@@ -1,6 +1,6 @@
-import sphinx_rtd_theme
-
-VERSION = open("../setup.py").read().split('version="')[1].split('"')[0]
+VERSION = (
+    open("../aiostream/__init__.py").read().split('__version__ = "')[1].split('"')[0]
+)
 
 project = "aiostream"
 version = VERSION
@@ -12,7 +12,6 @@ highlight_language = "python"
 extensions = ["sphinx.ext.autodoc"]
 
 html_theme = "sphinx_rtd_theme"
-html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
 html_context = {
     "display_github": True,
     "github_user": "vxgmichel",
