@@ -1,9 +1,11 @@
 import asyncio
-from aiostream import stream, operator
+from typing import AsyncIterator
+
+from aiostream import operator, stream
 
 
-async def main():
-    async def agen():
+async def main() -> None:
+    async def agen() -> AsyncIterator[int]:
         yield 1
         yield 2
         yield 3
@@ -26,6 +28,4 @@ async def main():
 
 
 # Run main coroutine
-loop = asyncio.get_event_loop()
-loop.run_until_complete(main())
-loop.close()
+asyncio.run(main())
